@@ -340,8 +340,6 @@ void TrackerList::showTrackerListMenu(QPoint) {
   if (!getSelectedTrackerItems().isEmpty()) {
     delAct = menu.addAction(IconProvider::instance()->getIcon("list-remove"), tr("Remove tracker"));
   }
-  menu.addSeparator();
-  QAction *reannounceAct = menu.addAction(IconProvider::instance()->getIcon("view-refresh"), tr("Force reannounce"));
   QAction *act = menu.exec(QCursor::pos());
   if (act == 0) return;
   if (act == addAct) {
@@ -352,10 +350,6 @@ void TrackerList::showTrackerListMenu(QPoint) {
     deleteSelectedTrackers();
     return;
   }
-  if (act == reannounceAct) {
-    properties->getCurrentTorrent().force_reannounce();
-    return;
-  }
 }
 
 void TrackerList::loadSettings() {
